Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3947)

Unified Diff: chrome/browser/tab_contents/infobar_delegate.h

Issue 3127009: Convert infobar APIs to UTF-16. (Closed)
Patch Set: works Created 10 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/tab_contents/infobar_delegate.h
diff --git a/chrome/browser/tab_contents/infobar_delegate.h b/chrome/browser/tab_contents/infobar_delegate.h
index 7be7b1efaadab844fc6c229a73945ed9529a4a0d..33336b81af38ea78e142cc04b13e748143671210 100644
--- a/chrome/browser/tab_contents/infobar_delegate.h
+++ b/chrome/browser/tab_contents/infobar_delegate.h
@@ -156,7 +156,7 @@ class InfoBarDelegate {
class AlertInfoBarDelegate : public InfoBarDelegate {
public:
// Returns the message string to be displayed for the InfoBar.
- virtual std::wstring GetMessageText() const = 0;
+ virtual string16 GetMessageText() const = 0;
// Overridden from InfoBarDelegate.
virtual SkBitmap* GetIcon() const { return NULL; }
@@ -178,15 +178,15 @@ class LinkInfoBarDelegate : public InfoBarDelegate {
public:
// Returns the message string to be displayed in the InfoBar. |link_offset|
// is the position where the link should be inserted. If |link_offset| is set
// to std::wstring::npos (it is by default), the link is right aligned within
// the InfoBar rather than being embedded in the message text.
- virtual std::wstring GetMessageTextWithOffset(size_t* link_offset) const {
- *link_offset = std::wstring::npos;
- return std::wstring();
+ virtual string16 GetMessageTextWithOffset(size_t* link_offset) const {
+ *link_offset = string16::npos;
+ return string16();
}
// Returns the text of the link to be displayed.
- virtual std::wstring GetLinkText() const = 0;
+ virtual string16 GetLinkText() const = 0;
// Overridden from InfoBarDelegate.
virtual SkBitmap* GetIcon() const { return NULL; }
@@ -231,7 +231,7 @@ class ConfirmInfoBarDelegate : public AlertInfoBarDelegate {
// Return the label for the specified button. The default implementation
// returns "OK" for the OK button and "Cancel" for the Cancel button.
- virtual std::wstring GetButtonLabel(InfoBarButton button) const;
+ virtual string16 GetButtonLabel(InfoBarButton button) const;
// Return whether or not the specified button needs elevation.
virtual bool NeedElevation(InfoBarButton button) const { return false; }
@@ -246,8 +246,8 @@ class ConfirmInfoBarDelegate : public AlertInfoBarDelegate {
// Returns the text of the link to be displayed, if any. Otherwise returns
// and empty string.
- virtual std::wstring GetLinkText() {
- return std::wstring();
+ virtual string16 GetLinkText() {
+ return string16();
}
// Called when the Link is clicked. The |disposition| specifies how the
@@ -278,19 +278,19 @@ class SimpleAlertInfoBarDelegate : public AlertInfoBarDelegate {
public:
// |icon| may be |NULL|.
SimpleAlertInfoBarDelegate(TabContents* contents,
- const std::wstring& message,
+ const string16& message,
SkBitmap* icon,
bool auto_expire);
// Overridden from AlertInfoBarDelegate:
virtual bool ShouldExpire(
const NavigationController::LoadCommittedDetails& details) const;
- virtual std::wstring GetMessageText() const;
+ virtual string16 GetMessageText() const;
virtual SkBitmap* GetIcon() const;
virtual void InfoBarClosed();
private:
- std::wstring message_;
+ string16 message_;
SkBitmap* icon_;
bool auto_expire_; // Should it expire automatically on navigation?
@@ -178,15 +178,15 @@ class LinkInfoBarDelegate : public InfoBarDelegate {
// Returns the message string to be displayed in the InfoBar. |link_offset|
// is the position where the link should be inserted. If |link_offset| is set
- // to std::wstring::npos (it is by default), the link is right aligned within
+ // to string16::npos (it is by default), the link is right aligned within
// the InfoBar rather than being embedded in the message text.

Powered by Google App Engine
This is Rietveld 408576698